==> ro-2.26.zip: ro/date.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%Y-%m-%d %H:%M'] = '%Y-%m-%d %H:%M';
L10n::$locales['_Jan'] = '_Ian';
L10n::$locales['_Feb'] = '_Feb';
L10n::$locales['_Mar'] = '_Mar';
L10n::$locales['_Apr'] = '_Apr';
L10n::$locales['_May'] = '_Mai';
L10n::$locales['_Jun'] = '_Iun';
L10n::$locales['_Jul'] = '_Iul';
L10n::$locales['_Aug'] = '_Aug';
L10n::$locales['_Sep'] = '_Sep';
L10n::$locales['_Oct'] = '_Oct';
L10n::$locales['_Nov'] = '_Noi';
L10n::$locales['_Dec'] = '_Dec';
L10n::$locales['January'] = 'Ianuarie';
L10n::$locales['February'] = 'Februarie';
L10n::$locales['March'] = 'Martie';
L10n::$locales['April'] = 'Aprilie';
L10n::$locales['May'] = 'Mai';
L10n::$locales['June'] = 'Iunie';
L10n::$locales['July'] = 'Iulie';
L10n::$locales['August'] = 'August';
L10n::$locales['September'] = 'Septembrie';
L10n::$locales['October'] = 'Octombrie';
L10n::$locales['November'] = 'Noiembrie';
L10n::$locales['December'] = 'Decembrie';
L10n::$locales['_Mon'] = '_Lun';
L10n::$locales['_Tue'] = '_Mar';
L10n::$locales['_Wed'] = '_Mie';
L10n::$locales['_Thu'] = '_Joi';
L10n::$locales['_Fri'] = '_Vin';
L10n::$locales['_Sat'] = '_Sâm';
L10n::$locales['_Sun'] = '_Dum';
L10n::$locales['Monday'] = 'Luni';
L10n::$locales['Tuesday'] = 'Marţi';
L10n::$locales['Wednesday'] = 'Miercuri';
L10n::$locales['Thursday'] = 'Joi';
L10n::$locales['Friday'] = 'Vineri';
L10n::$locales['Saturday'] = 'Sâmbătă';
L10n::$locales['Sunday'] = 'Duminică';

==> ro-2.28.zip: ro/date.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%Y-%m-%d %H:%M'] = '%Y-%m-%d %H:%M';
L10n::$locales['_Jan'] = '_Ian';
L10n::$locales['_Feb'] = 'Feb';
L10n::$locales['_Mar'] = '_Mar';
L10n::$locales['_Apr'] = '_Apr';
L10n::$locales['_May'] = '_Mai';
L10n::$locales['_Jun'] = '_Iun';
L10n::$locales['_Jul'] = '_Iul';
L10n::$locales['_Aug'] = '_Aug';
L10n::$locales['_Sep'] = '_Sep';
L10n::$locales['_Oct'] = 'Oct';
L10n::$locales['_Nov'] = '_Noi';
L10n::$locales['_Dec'] = '_Decembrie';
L10n::$locales['January'] = 'Ianuarie';
L10n::$locales['February'] = 'Februarie';
L10n::$locales['March'] = 'Martie';
L10n::$locales['April'] = 'Aprilie';
L10n::$locales['May'] = 'Mai';
L10n::$locales['June'] = 'Iunie';
L10n::$locales['July'] = 'Iulie';
L10n::$locales['August'] = 'august';
L10n::$locales['September'] = 'Septembrie';
L10n::$locales['October'] = 'Octombrie';
L10n::$locales['November'] = 'Noiembrie';
L10n::$locales['December'] = 'Decembrie';
L10n::$locales['_Mon'] = '_Lun';
L10n::$locales['_Tue'] = '_Mar';
L10n::$locales['_Wed'] = '_Mie';
L10n::$locales['_Thu'] = '_Joi';
L10n::$locales['_Fri'] = '_Vin';
L10n::$locales['_Sat'] = '_Sâm';
L10n::$locales['_Sun'] = '_Dum';
L10n::$locales['Monday'] = 'Luni';
L10n::$locales['Tuesday'] = 'Marţi';
L10n::$locales['Wednesday'] = 'Miercuri';
L10n::$locales['Thursday'] = 'Joi';
L10n::$locales['Friday'] = 'Vineri';
L10n::$locales['Saturday'] = 'Sâmbătă';
L10n::$locales['Sunday'] = 'Duminică';
